Module cell

Module cell 

A shareable mutable container.

Structs

JSCell
A cell for interior mutability, that (ab)uses NoGC as a borrow token for ensuring safety.
JSRefCell
std::cell::RefCell that statically prevents borrow_mut panics from occurring by borrowing due to GC using the NoGC marker.
Ref
Wraps a borrowed reference to a value in a RefCell box. A wrapper type for an immutably borrowed value from a RefCell<T>.
RefMut
A wrapper type for a mutably borrowed value from a RefCell<T>.

Functions

three_cells_borrow_mut
Mutably borrows three different JSCells at the same time.
two_cells_borrow_mut
Mutably borrows two different JSCells at the same time.