#[repr(C)]pub struct RegExpFlags {
pub flags_: u8,
}Expand description
A collection of regular expression flags. Individual flag values may be combined into a collection using bitwise operators.
Fields
flags_: u8Trait Implementations
Sourceimpl Clone for RegExpFlags
impl Clone for RegExpFlags
Sourcefn clone(&self) -> RegExpFlags
fn clone(&self) -> RegExpFlags
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for RegExpFlags
Sourceimpl Debug for RegExpFlags
impl Debug for RegExpFlags
Sourceimpl PartialEq for RegExpFlags
impl PartialEq for RegExpFlags
Sourcefn eq(&self, other: &RegExpFlags) -> bool
fn eq(&self, other: &RegExpFlags) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RegExpFlags