pub struct ParentRuntime { /* private fields */ }Expand description
A handle to a Runtime that will be used to create a new runtime in another thread. This handle and the new runtime must be destroyed before the original runtime can be dropped.