A shareable mutable container.
Structs
- JSCell
- A cell for interior mutability, that (ab)uses NoGC as a borrow token for ensuring safety.
- JSRef
Cell std::cell::RefCellthat statically prevents borrow_mut panics from occurring by borrowing due to GC using theNoGCmarker.- Ref
- Wraps a borrowed reference to a value in a
RefCellbox. A wrapper type for an immutably borrowed value from aRefCell<T>. - RefMut
- A wrapper type for a mutably borrowed value from a
RefCell<T>.
Functions
- three_
cells_ borrow_ mut - Mutably borrows three different
JSCells at the same time. - two_
cells_ borrow_ mut - Mutably borrows two different
JSCells at the same time.